﻿using System;
using Microsoft.SPOT;
using Microsoft.SPOT.Hardware;
using Microsoft.SPOT.Presentation.Media;
using System.Threading;
using DeviceSolutions.SPOT.Hardware;

namespace UIDemo_BitmapMode
{
    public static class Program
    {
        static Color ColorRoyalBlue = ColorUtility.ColorFromRGB(0x41, 0x69, 0xE1);
        static Color ColorPapayaWhip= ColorUtility.ColorFromRGB(0xFF, 0xEF, 0xD5);
        static Color ColorMediumSpringGreen = ColorUtility.ColorFromRGB(0x00, 0xFA, 0x9A);
        static Color ColorYellow = ColorUtility.ColorFromRGB(0xFF, 0xFF, 0x00);
        static Color ColorGrey = ColorUtility.ColorFromRGB(0xC0, 0xC0, 0xC0);

        static InputPort _buttonAction = new InputPort(TahoeII.Pins.SW7, true, Port.ResistorMode.PullUp);

        public static void Main()
        {
            int w,h,d,r;
            
            HardwareProvider.HwProvider.GetLCDMetrics(out w,out h,out d,out r);

            Bitmap bmp = new Bitmap(w, h);

            //// Testo
            bmp.DrawText("Testo con Font NinaB", Resources.GetFont(Resources.FontResources.NinaB), ColorUtility.ColorFromRGB(255, 0, 0), 10, 5);
            bmp.DrawText("Testo con Font Small", Resources.GetFont(Resources.FontResources.small), ColorUtility.ColorFromRGB(0, 255, 0), 10, 20);

            // Rettangolo pieno
            bmp.DrawRectangle(Color.White,
                0,
                10, 50, 50, 50,
                0, 0,
                ColorRoyalBlue, 0, 0,
                ColorRoyalBlue, 0, 0,
                Bitmap.OpacityOpaque);

            // Rettangolo vuoto
            bmp.DrawRectangle(ColorRoyalBlue,
                3,
                70, 50, 50, 50,
                0, 0,
                Color.Black, 0, 0,
                Color.Black, 0, 0,
                Bitmap.OpacityTransparent);

            // Rettangolo vuoto "rounded"
            bmp.DrawRectangle(ColorRoyalBlue,
                1,
                130, 50, 50, 50,
                5, 5,
                Color.Black, 0, 0,
                Color.Black, 0, 0,
                Bitmap.OpacityTransparent);

            // Rettangolo gradient orizzontale
            bmp.DrawRectangle(ColorRoyalBlue,
                0,
                190, 50, 50, 50,
                0, 0,
                ColorRoyalBlue, 190, 50,
                Color.White, 190 + 50, 50,
                Bitmap.OpacityOpaque);

            // Rettangolo gradient verticale
            bmp.DrawRectangle(ColorRoyalBlue,
                0,
                250, 50, 50, 50,
                0, 0,
                ColorRoyalBlue, 250, 50,
                Color.White, 250, 50 + 50,
                Bitmap.OpacityOpaque);

            // Test trasparenza
            for (ushort opacity = 0; opacity < 200; opacity += 16)
            {
                bmp.DrawRectangle(Color.White,
                    0,
                    10 + opacity, 100 + opacity / 8, 50, 50,
                    0, 0,
                    ColorPapayaWhip, 0, 0,
                    ColorPapayaWhip, 0, 0,
                    opacity);
            }

            // Ellissi
            bmp.DrawEllipse(ColorUtility.ColorFromRGB(255, 0, 0), 30, 190, 25, 25);
            bmp.DrawEllipse(ColorUtility.ColorFromRGB(0, 255, 0), 40, 210, 25, 25);
            bmp.DrawEllipse(ColorUtility.ColorFromRGB(0, 0, 255), 50, 190, 25, 25);

            // NON IMPLEMENTATO IN .NET MF 4.0
            //bmp.DrawEllipse(ColorYellow, 0,90,200,25,25,ColorYellow,90,200,ColorMediumSpringGreen,100,210,Bitmap.OpacityOpaque);

            // Immagini
            Bitmap bmpIcon1 = Resources.GetBitmap(Resources.BitmapResources.netmf);
            bmp.DrawImage(100, 190, bmpIcon1, 0, 0, bmpIcon1.Width, bmpIcon1.Height);

            bmp.Flush();

            // Attendo la pressione del pulsante Action
            while (_buttonAction.Read())
            {
                Thread.Sleep(10);
            }

            // Pulisco lo schermo...
            bmp.Clear();
            bmp.Flush();

            // Divisione del reticolo...
            int xdivs = 10;
            int ydivs = 10;
            int oldx = 0, oldy = 0;

            while (true)
            {
                oldx = -1;
                oldy = -1;

                // Pulisco la bitmap
                bmp.Clear();

                // Bordo...
                bmp.DrawRectangle(ColorGrey, 1, 0, 0, w, h, 0, 0, Color.White, 0, 0, Color.White, 0, 0, Bitmap.OpacityTransparent);


                // reticolo...
                for (int xi = 0; xi < xdivs; xi++)
                {
                    bmp.DrawLine(ColorGrey, 1, xi * (w / xdivs), 0, xi * (w / xdivs), h);
                }

                for (int yi = 0; yi < ydivs; yi++)
                {
                    bmp.DrawLine(ColorGrey, 1, 0, yi * (h / ydivs), w, yi * (h / ydivs));
                }

                bmp.DrawText("AUX", Resources.GetFont(Resources.FontResources.small), ColorUtility.ColorFromRGB(255, 0, 0), 294, 6);

                bmp.Flush();

                // Scansione e lettura ADC
                for (int xi = 0; xi < w; xi++)
                {
                    //float scaledtemp=(TahoeII.Tsc2046.ReadAux()) / 3.3f;

                    float scaledtemp = 1.0f+Microsoft.SPOT.Math.Sin(xi)/1000.0f;

                    int yt = h-(int)(scaledtemp*h/2);

                    if (oldx != -1)
                    {
                        // Linea che unisce gli ultimi 2 punti rilevati...
                        bmp.DrawLine(ColorUtility.ColorFromRGB(255, 0, 0), 1, oldx, oldy, xi, yt);

                        bmp.Flush();
                    }

                    oldx = xi - 1;
                    oldy = yt;

                    Thread.Sleep(10);
                }

            }

        }

    }
}
